CoW B+ tree engine.
All mutations use Copy-on-Write: the old page is cloned to a new page ID, modified, and ancestors are updated to point to the new page. Old pages are freed via the allocator’s pending-free list.
The tree uses HashMap<PageId, Page> as the in-memory page store.
Structs
- BTree
- B+ tree metadata. Lightweight struct — pages are stored externally.