pub struct Cursor { /* private fields */ }Expand description
Cursor position within the B+ tree. Stores the path from root to the current leaf.
Implementations
Sourceimpl Cursor
impl Cursor
Sourcepub fn seek(
pages: &HashMap<PageId, Page>,
root: PageId,
key: &[u8],
) -> Result<Self>
pub fn seek( pages: &HashMap<PageId, Page>, root: PageId, key: &[u8], ) -> Result<Self>
Position the cursor at the first key >= key (seek).
If key is empty, positions at the first entry in the tree.
Sourcepub fn first(pages: &HashMap<PageId, Page>, root: PageId) -> Result<Self>
pub fn first(pages: &HashMap<PageId, Page>, root: PageId) -> Result<Self>
Position the cursor at the first entry in the tree.
Sourcepub fn last(pages: &HashMap<PageId, Page>, root: PageId) -> Result<Self>
pub fn last(pages: &HashMap<PageId, Page>, root: PageId) -> Result<Self>
Position the cursor at the last entry in the tree.
Sourcepub fn current(&self, pages: &HashMap<PageId, Page>) -> Option<CursorEntry>
pub fn current(&self, pages: &HashMap<PageId, Page>) -> Option<CursorEntry>
Get the current entry without advancing.